/*
 *	      UNIX is a registered trademark of AT&T
 *		Portions Copyright 1976-1990 AT&T
 *	Portions Copyright 1980-1989 Microsoft Corporation
 *   Portions Copyright (C) 1983-1991 The Santa Cruz Operation, Inc
 *		      All Rights Reserved
 *      The information in this file is provided for the exclusive use of
 *      the licensees of The Santa Cruz Operation, Inc.  Such users have the
 *      right to use, modify, and incorporate this code into other products
 *      for purposes authorized by the license agreement provided they include
 *      this notice and the associated copyright notice with any such product.
 *      The information in this file is provided "AS IS" without warranty.
 *
 *		Copyright (c) 1984, 1986, 1987, 1988 AT&T
 *			  All Rights Reserved
 *
 *	THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AT&T
 *	The copyright notice above does not evidence any
 *	actual or intended publication of such source code.
 *
 */

#ifndef _MATH_H
#define _MATH_H

#ifdef __STDC__
#pragma comment(exestr, "@(#) math.h 10.3 92/04/21 ")
#else
#ident "@(#) math.h 10.3 92/04/21 "
#endif /* __STDC__ */

#if  !_STRICT_NAMES && !defined(_STRICTNAME_H)
#include  <strictname.h>
#endif

#ifdef	_M_I386
#pragma	pack(4)
#else
#pragma	pack(2)
#endif


#if !_STRICT_NAMES
extern int errno;
#endif /* _STRICT_NAMES */

#if !__STDC__
#ifndef	_STRUCT_EXCEPTION
#define	_STRUCT_EXCEPTION
struct exception {
 int type;
 char *name;
 double arg1;
 double arg2;
 double retval;
};
#endif
#endif /* !__STDC__ */

#if defined(_NO_PROTOTYPE)
extern double acos();
extern double asin();
extern double atan();
extern double atan2();
extern double cos();
extern double sin();
extern double tan();
extern double cosh();
extern double sinh();
extern double tanh();
extern double exp();
extern double frexp();
extern double ldexp();
extern double log();
extern double log10();
extern double modf();
extern double pow();
extern double sqrt();
extern double ceil();
extern double fabs();
extern double floor();
extern double fmod();
#if defined(_XOPEN_SOURCE) || !__STDC__
extern int    isnan();
extern double lgamma();
extern double erf();
extern double erfc();
extern double j0();
extern double j1();
extern double jn();
extern double y0();
extern double y1();
extern double yn();
extern double gamma();
extern double hypot();
#endif /* _XOPEN_SOURCE || !__STDC__ */
#if !__STDC__
extern int matherr();
#endif /* !__STDC__ */

#else /* _NO_PROTOTYPE */

#if __cplusplus
extern "C" {
#endif /* __cplusplus */

extern double acos(double);
extern double asin(double);
extern double atan(double);
extern double atan2(double, double);
extern double cos(double);
extern double sin(double);
extern double tan(double);
extern double cosh(double);
extern double sinh(double);
extern double tanh(double);
extern double exp(double);
extern double frexp(double, int *);
extern double ldexp(double, int);
extern double log(double);
extern double log10(double);
extern double modf(double, double *);
extern double pow(double, double);
extern double sqrt(double);
extern double ceil(double);
extern double fabs(double);
extern double floor(double);
extern double fmod(double, double);
#if defined(_XOPEN_SOURCE) || !__STDC__
extern int    isnan(double);
extern double lgamma(double);
extern double erf(double);
extern double erfc(double);
extern double j0(double);
extern double j1(double);
extern double jn(int, double);
extern double y0(double);
extern double y1(double);
extern double yn(int, double);
extern double gamma(double);
extern double hypot(double, double);
#endif /* _XOPEN_SOURCE || !__STDC__ */
#if !__STDC__
extern int matherr(struct exception *);
#endif /* !__STDC__ */

#if __cplusplus
extern double atof(const char*);	/* Obsolete should get from stdlib.h */
};	/* Close off extern "C" */




#ifndef _ABS_INL
#define _ABS_INL


#endif

#endif /* __cplusplus */

#endif /* _NO_PROTOTYPE */

#ifndef HUGE_VAL
#define HUGE_VAL (1.7976931348623157e+308)
#endif

#if defined(_XOPEN_SOURCE) || !__STDC__
extern int signgam;
#define M_E            2.7182818284590452354
#define M_LOG2E        1.4426950408889634074
#define M_LOG10E       0.43429448190325182765
#define M_LN2          0.69314718055994530942
#define M_LN10         2.30258509299404568402
#define M_PI           3.14159265358979323846
#define M_PI_2         1.57079632679489661923
#define M_PI_4         0.78539816339744830962
#define M_1_PI         0.31830988618379067154
#define M_2_PI         0.63661977236758134308
#define M_2_SQRTPI     1.12837916709551257390
#define M_SQRT2        1.41421356237309504880
#define M_SQRT1_2      0.70710678118654752440
#define MAXFLOAT     ((float)3.40282346638528860e+38)
#endif /* _XOPEN_SOURCE || !__STDC__ */

#if __cplusplus	&& !defined(PI)
#define PI M_PI
#endif	/* __cplusplus */

#if !__STDC__
#define HUGE           MAXFLOAT
#define DOMAIN       1
#define SING         2
#define OVERFLOW     3
#define UNDERFLOW    4
#define TLOSS        5
#define PLOSS        6
#define _ABS(x) ((x) < 0 ? -(x) : (x))
#define _REDUCE(TYPE, X, XN, C1, C2) \
  { \
   double __x1, __x2; __x1 = (double)(TYPE)(X), __x2 = (X) - __x1; \
   (X)  = __x1 - (XN) * (C1); (X) += __x2; (X) -= (XN) * (C2); \
  }
#define _POLY1(x, c) ((c)[0] * (x) + (c)[1])
#define _POLY2(x, c) (_POLY1((x), (c)) * (x) + (c)[2])
#define _POLY3(x, c) (_POLY2((x), (c)) * (x) + (c)[3])
#define _POLY4(x, c) (_POLY3((x), (c)) * (x) + (c)[4])
#define _POLY5(x, c) (_POLY4((x), (c)) * (x) + (c)[5])
#define _POLY6(x, c) (_POLY5((x), (c)) * (x) + (c)[6])
#define _POLY7(x, c) (_POLY6((x), (c)) * (x) + (c)[7])
#define _POLY8(x, c) (_POLY7((x), (c)) * (x) + (c)[8])
#define _POLY9(x, c) (_POLY8((x), (c)) * (x) + (c)[9])
#endif /* !__STDC__ */

/* hack for math library intrinsics problems */
/*
 *	The problem here is that the Microsoft cc compiler will
 * attempt to optimize some math functions when invoked with -Oi.
 *	Unfortunately, the optimized functions are not available under SCO
 * Unix or Xenix and hence we have to ensure that the functions themselves
 * are called.
 */

/*
 *	This code should be changed prior to the next release.  At that
 * point the -Oi command will be altered to ONLY inline the intrinsics that
 * are both documented and "sensible"
 */
#ifdef __STDC__
#pragma function( pow, log, log10, exp)
#pragma function( sin, cos, tan)
#pragma function( asin, acos, atan, atan2)
#pragma function( sinh, cosh, tanh)
#pragma function( sqrt)
#pragma function(fmod)
/* #pragma function(fabs)	This function is provided by SCO */
#endif /* __STDC__ */

#pragma	pack()

#endif /* _MATH_H	*/
