#ifndef _SYS_WAIT_H
#define _SYS_WAIT_H
#ifdef __STDC__
#pragma comment(exestr, "@(#) wait.h 25.3 92/08/03 ")
#else
#ident "@(#) wait.h 25.3 92/08/03 "
#endif
/*
 *	Copyright (C) 1988-1992 The Santa Cruz Operation, Inc.
 *		All Rights Reserved.
 *	The information in this file is provided for the exclusive use of
 *	the licensees of The Santa Cruz Operation, Inc.  Such users have the
 *	right to use, modify, and incorporate this code into other products
 *	for purposes authorized by the license agreement provided they include
 *	this notice and the associated copyright notice with any such product.
 *	The information in this file is provided "AS IS" without warranty.
 */
/*	Copyright (c) 1987, 1988 Microsoft Corporation	*/
/*	  All Rights Reserved	*/

/*	This Module contains Proprietary Information of Microsoft  */
/*	Corporation and should be treated as Confidential.	   */

/*
 * New for POSIX
 */

/*
 * Option bits for the third argument of waitpid().  WNOHANG causes the
 * wait to not hang if there are no stopped or terminated processes, rather
 * returning an error indication in this case (pid==0).  WUNTRACED
 * indicates that the caller should receive status about untraced children
 * which stop due to signals.  If children are stopped and a wait without
 * this option is done, it is as though they were still running... nothing
 * about them is returned.
 */
#define         WNOHANG         1       /* don't hang in wait */
#define         WUNTRACED       2       /* tell about stopped, untraced children */

#ifdef __SCO_WAIT3__
/*	from wait.h 5.1.1.2 Lachman System V STREAMS TCP source		*/

/*
 * Structure of the information in the first word returned by both
 * wait and wait3.  If w_stopval==WSTOPPED, then the second structure
 * describes the information returned, else the first.  See WUNTRACED below.
 */
union wait      {
        int     w_status;               /* used in syscall */
        /*
         * Terminated process status.
         */
        struct {
                unsigned short  w_Termsig:7;    /* termination signal */
                unsigned short  w_Coredump:1;   /* core dump indicator */
                unsigned short  w_Retcode:8;    /* exit code if w_termsig==0 */
        } w_T;
        /*
         * Stopped process status.  Returned
         * only for traced children unless requested
         * with the WUNTRACED option bit.
         */
        struct {
                unsigned short  w_Stopval:8;    /* == W_STOPPED if stopped */
                unsigned short  w_Stopsig:8;    /* signal that stopped us */
        } w_S;
};
#define w_termsig       w_T.w_Termsig
#define w_coredump      w_T.w_Coredump
#define w_retcode       w_T.w_Retcode
#define w_stopval       w_S.w_Stopval
#define w_stopsig       w_S.w_Stopsig

#define	WSTOPPED	0177	/* value of s.stopval if process is stopped */

#endif /* __SCO_WAIT3__ */

/*
 * macros to interpret stat_loc from wait(stat_loc) and waitpid(,stat_loc,)
 */
#define         WIFEXITED(sv)           ((sv & 0xff) == 0)
#define         WEXITSTATUS(sv)         ((sv >> 8) & 0xff)
#define         WIFSIGNALED(sv)         ((sv) && (sv == (sv & 0x00ff)))
#define         WTERMSIG(sv)             (sv & 0x7f)
#define         WIFSTOPPED(sv)          ((sv & 0xff) == 0177)
#define         WSTOPSIG(sv)            ((sv >> 8) & 0xff)

/*
 * if WIFSIGNALED(sv) is true, then WCOREDUMP(sv)
 *  tells if core was (successfully) dumped ...
 */
#if !defined(_POSIX_SOURCE) && !defined(_XOPEN_SOURCE)
# define	WCOREFLG		0x80
# define	WCOREDUMP(sv)		((sv) & WCOREFLG)
#endif

#ifndef _INKERNEL

#include <sys/types.h>

#ifdef _NO_PROTOTYPE
extern pid_t	wait();
extern pid_t	waitpid();
#else
#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */
extern pid_t	wait(int *);
extern pid_t	waitpid(pid_t, int *, int);
#ifdef __cplusplus
};
#endif /* __cplusplus */
#endif /* _NO_PROTOTYPE */
#endif /* !_INKERNEL */

#endif	/* _SYS_WAIT_H */
